@@ -261,12 +261,12 @@ class APIRequestor(object):
         # - TrustedRoot
         # - DigiCert High Assurance EV - 1
         # - Clever.com EV
-        # 
-        # This ensures that only this certificate chain is used to verify SSL certs. 
+        #
+        # This ensures that only this certificate chain is used to verify SSL certs.
         # Certs dervived from other ca certs will be treated as invalid.
         # eg. https://api.twitter.com and https://api.stripe.com FAIL
-        #     https://api.clever.com and https://api.github.com PASS 
-        # 
+        #     https://api.clever.com and https://api.github.com PASS
+        #
         # TODO: This gets us close to CERT PINNING but we need to pin the entire chain not just the CA
         result = requests.request(meth, abs_url,
                                   headers=headers, data=data, timeout=80,
@@ -623,10 +623,25 @@ class APIResource(CleverObject):
 class ListableAPIResource(APIResource):
   @classmethod
   def all(cls, api_key=None, **params):
+    return list(cls.iter(api_key, **params))
+
+  @classmethod
+  def iter(cls, api_key=None, **params):
+    for unsupported_param in ['limit', 'page']:
+      if unsupported_param in params:
+        raise CleverError("ListableAPIResource does not support '%s' parameter" % (unsupported_param,))
+
     requestor = APIRequestor(api_key)
     url = cls.class_url()
-    response, api_key = requestor.request('get', url, params)
-    return convert_to_clever_object(cls, response, api_key)
+    params['page'] = 1
+    params['limit'] = 1000
+    done_paginating = False
+    while not done_paginating:
+      response, api_key = requestor.request('get', url, params)
+      for datum in convert_to_clever_object(cls, response, api_key):
+        yield datum
+      params['page'] += 1
+      done_paginating = len(response['data']) < params['limit']
 
 class CreatableAPIResource(APIResource):
   @classmethod
